/************************************************************************
 * Copyright (c) 2008 by Gregor Ehrenstein (grx@pandacube.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ************************************************************************/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace SudokuSolver
{
    /// <summary>
    /// This Form shows a small About window with the current version of the program and
    /// a link to the homepage. It uses a picture that is saved as a resource within the
    /// executable as background.
    /// </summary>
    public partial class AboutForm1 : Form
    {
        /// <summary>
        /// Standard Constuctor that initializes the GUI.
        /// </summary>
        public AboutForm1()
        {
            InitializeComponent();
        }

        /// <summary>
        /// This Method gets called when the window is created. It loads the background image
        /// from the executable
        /// </summary>
        private void AboutForm1_Load(object sender, EventArgs e)
        {
            // load about image
            System.IO.Stream st;
            System.Reflection.Assembly a = System.Reflection.Assembly.GetExecutingAssembly();
            st = a.GetManifestResourceStream("SudukoSolver.Resources.PandaCubeSmall.png");
            pictureBox1.Image = Image.FromStream(st);
        }

        /// <summary>
        /// This method gets called when the ok-button is pressed in the about window.
        /// It closes the about window.
        /// </summary>
        private void OkButton1_Click(object sender, EventArgs e)
        {
            // close window on button press
            this.Close();
        }

        /// <summary>
        /// This method get called when the link to the project website is clicked. It opens
        /// the standard webbrowser with the correct web address.
        /// </summary>
        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            // start webbrowser if link is clicked
            System.Diagnostics.Process.Start("http://www.pandacube.de");
        }
    }
}